@@ -14,10 +14,13 @@ pub use self::{
 
 use std::{
     ffi::{self, CStr},
-    fmt, mem,
+    fmt, io, mem,
 };
 
-use noodles_sam as sam;
+use noodles_sam::{
+    self as sam,
+    header::{ReferenceSequence, ReferenceSequences},
+};
 
 pub(crate) const UNMAPPED_POSITION: i32 = -1;
 
@@ -409,6 +412,96 @@ impl Record {
     }
 }
 
+impl sam::RecordExt for Record {
+    /// Returns the associated reference sequence.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use noodles_bam as bam;
+    /// use noodles_sam::{header::ReferenceSequences, RecordExt};
+    ///
+    /// let record = bam::Record::default();
+    /// let reference_sequences = ReferenceSequences::default();
+    ///
+    /// assert!(record.reference_sequence(&reference_sequences).is_none());
+    /// ```
+    fn reference_sequence<'rs>(
+        &self,
+        reference_sequences: &'rs ReferenceSequences,
+    ) -> Option<io::Result<&'rs ReferenceSequence>> {
+        get_reference_sequence(reference_sequences, self.reference_sequence_id())
+    }
+
+    /// Returns the start position.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use noodles_bam as bam;
+    /// use noodles_sam::RecordExt;
+    /// let record = bam::Record::default();
+    /// assert!(record.alignment_start().is_none());
+    /// ```
+    fn alignment_start(&self) -> Option<sam::record::Position> {
+        self.position()
+    }
+
+    /// Calculates the alignment span over the reference sequence.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// # use std::io;
+    /// use noodles_bam as bam;
+    /// use noodles_sam::RecordExt;
+    /// let record = bam::Record::default();
+    /// assert_eq!(record.alignment_span()?, 0);
+    /// # Ok::<_, io::Error>(())
+    /// ```
+    fn alignment_span(&self) -> io::Result<u32> {
+        self.cigar().reference_len()
+    }
+
+    /// Returns the associated reference sequence of the mate.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use noodles_bam as bam;
+    /// use noodles_sam::{header::ReferenceSequences, RecordExt};
+    ///
+    /// let record = bam::Record::default();
+    /// let reference_sequences = ReferenceSequences::default();
+    ///
+    /// assert!(record.mate_reference_sequence(&reference_sequences).is_none());
+    /// ```
+    fn mate_reference_sequence<'rs>(
+        &self,
+        reference_sequences: &'rs ReferenceSequences,
+    ) -> Option<io::Result<&'rs ReferenceSequence>> {
+        get_reference_sequence(reference_sequences, self.mate_reference_sequence_id())
+    }
+}
+
+fn get_reference_sequence(
+    reference_sequences: &ReferenceSequences,
+    reference_sequence_id: Option<ReferenceSequenceId>,
+) -> Option<io::Result<&ReferenceSequence>> {
+    reference_sequence_id.map(|reference_sequence_id| {
+        usize::try_from(i32::from(reference_sequence_id))
+            .map_err(|e| io::Error::new(io::ErrorKind::InvalidData, e))
+            .and_then(|i| {
+                reference_sequences
+                    .get_index(i)
+                    .map(|(_, rs)| rs)
+                    .ok_or_else(|| {
+                        io::Error::new(io::ErrorKind::InvalidData, "invalid reference sequence ID")
+                    })
+            })
+    })
+}
+
 impl Default for Record {
     fn default() -> Self {
         use sam::record::{Flags, MappingQuality};
